{
  "type": "record",
  "name": "ContainerKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "doc": "Key for an Asset Container",
  "fields": [
    {
      "name": "guid",
      "type": [
        "null",
        "string"
      ],
      "doc": "Unique guid for container",
      "default": null
    }
  ],
  "Aspect": {
    "name": "containerKey"
  }
}